@@ -108,7 +108,9 @@ class _MessageHandler(_Base):
 
         datasource_key = j['data']['datasourceKey']
         trainer_key = j['data']['trainerKey']
-        hyper_param_values = j['data']['hyperParamValues']
+        hyper_param_values = {}
+        if 'hyperParamValues' in j['data']:
+            hyper_param_values = j['data']['hyperParamValues']
         not_sampled = False
         if 'notSampled' in j['data']:
             not_sampled = j['data']['notSampled']
@@ -132,6 +134,7 @@ class _MessageHandler(_Base):
             'project_key': project_key,
             'datasource_key': datasource_key,
             'trainer_key': trainer_key,
+            'hyper_param_values': hyper_param_values,
         }
 
         if datasource_type == 'label':
@@ -165,7 +168,7 @@ class _MessageHandler(_Base):
                 trainers = ds.trainers[p['trainer_key']]
 
                 file_path = get_vertical_file_path(mode, project_key, ds.key, round)
-                trainers['train'](j['data']['batch'], file_path)
+                trainers['train'](j['data']['batch'], file_path, ds.key, p['hyper_param_values'])
 
                 upload_url = self._make_request('POST', f'/projects/{project_key}/vertical/upload', {
                     'round': round,
@@ -205,7 +208,7 @@ class _MessageHandler(_Base):
                 with open(gradients_path, 'wb') as f:
                     f.write(r.content)
 
-                trainers['test'](j['data']['batch'], gradients_path)
+                trainers['test'](j['data']['batch'], gradients_path, ds.key, p['hyper_param_values'])
 
     def label_train(self, j, project_key):
         for p in self.state.label_participants:
@@ -231,7 +234,7 @@ class _MessageHandler(_Base):
                     f.write(r.content)
 
                 # Start training
-                trainers['train'](j['data']['batch'], activations_path, gradients_path)
+                trainers['train'](j['data']['batch'], activations_path, gradients_path, ds.key, p['hyper_param_values'])
 
                 # Upload gradients
                 upload_url = self._make_request('POST', f'/projects/{project_key}/vertical/upload', {
@@ -272,7 +275,7 @@ class _MessageHandler(_Base):
                 with open(activations_path, 'wb') as f:
                     f.write(r.content)
 
-                result = trainers['test'](j['data']['batch'], activations_path)
+                result = trainers['test'](j['data']['batch'], activations_path, ds.key, p['hyper_param_values'])
                 print('round: ', j['data']['project']['currentRound'], 'result: ', result)
 
                 # Upload result to stats endpoint
