@@ -107,13 +107,13 @@ class _Project(_Base):
             r.raise_for_status()
 
             try:
-                self._make_request('POST', url, print_error=False)
+                self._make_request('POST', url)
             except Exception as e:
                 if str(e).find('Model will not be uploaded.'):
                     print('Model not sampled.')
                 else:
                     raise e
-            
+
     """
         Uploads pre-intersected list of ids to newly created project.
     """
