@@ -155,13 +155,15 @@ class _State(_Base):
             # Valid types are 'label' and 'feature'
             params['type'] = type
 
-
-        found_datasources = self._make_request('GET', '/datasources', params={'key': key}, list=True)
-        if len(found_datasources):
+        try:
+            self._make_request('GET', f'/datasources/{key}', print_error=False)
+            # Datasource exists so update it
             self._make_request('POST', f'/datasources/{key}', params=params)
-        else:
+            print(f'>>> Updated datasource "{key}"')
+        except:
+            # Datasource doesn't exist so create it
             self._make_request('POST', '/datasources', params=params)
-
+            print(f'>>> Created datasource "{key}"')
 
         ds = _Datasource(self, key, type)
         self.datasources[key] = ds
