@@ -1,6 +1,6 @@
 from .State import _State
 from .MessageHandler import _MessageHandler
-from .helpers import _Helpers
+from .Helpers import _Helpers
 
 RETRY_AFTER = 5 # seconds
 
